==> zio-aws-elasticloadbalancing_2.12-5.17.126.2-sources.jar: zio/aws/elasticloadbalancing/model/ConfigureHealthCheckResponse.scala <==
package zio.aws.elasticloadbalancing.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ConfigureHealthCheckResponse(
    healthCheck: Option[zio.aws.elasticloadbalancing.model.HealthCheck] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse = {
    import ConfigureHealthCheckResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
      .builder()
      .optionallyWith(healthCheck.map(value => value.buildAwsValue()))(
        _.healthCheck
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse.ReadOnly =
    zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse
      .wrap(buildAwsValue())
}
object ConfigureHealthCheckResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse =
      zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse(
        healthCheck.map(value => value.asEditable)
      )
    def healthCheck
        : Option[zio.aws.elasticloadbalancing.model.HealthCheck.ReadOnly]
    def getHealthCheck: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancing.model.HealthCheck.ReadOnly
    ] = AwsError.unwrapOptionField("healthCheck", healthCheck)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
  ) extends zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse.ReadOnly {
    override val healthCheck
        : Option[zio.aws.elasticloadbalancing.model.HealthCheck.ReadOnly] =
      scala
        .Option(impl.healthCheck())
        .map(value =>
          zio.aws.elasticloadbalancing.model.HealthCheck.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
  ): zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticloadbalancing_2.13-5.17.214.1-sources.jar: zio/aws/elasticloadbalancing/model/ConfigureHealthCheckResponse.scala <==
package zio.aws.elasticloadbalancing.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ConfigureHealthCheckResponse(
    healthCheck: Optional[zio.aws.elasticloadbalancing.model.HealthCheck] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse = {
    import ConfigureHealthCheckResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
      .builder()
      .optionallyWith(healthCheck.map(value => value.buildAwsValue()))(
        _.healthCheck
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse.ReadOnly =
    zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse
      .wrap(buildAwsValue())
}
object ConfigureHealthCheckResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse =
      zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse(
        healthCheck.map(value => value.asEditable)
      )
    def healthCheck
        : Optional[zio.aws.elasticloadbalancing.model.HealthCheck.ReadOnly]
    def getHealthCheck: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancing.model.HealthCheck.ReadOnly
    ] = AwsError.unwrapOptionField("healthCheck", healthCheck)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
  ) extends zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse.ReadOnly {
    override val healthCheck
        : Optional[zio.aws.elasticloadbalancing.model.HealthCheck.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheck())
        .map(value =>
          zio.aws.elasticloadbalancing.model.HealthCheck.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.ConfigureHealthCheckResponse
  ): zio.aws.elasticloadbalancing.model.ConfigureHealthCheckResponse.ReadOnly =
    new Wrapper(impl)
}
